@@ -1,5 +1,5 @@
 # Verilog - Verilog Perl Interface
-# $Revision: #27 $$Date: 2004/04/01 $$Author: wsnyder $
+# $Revision: #30 $$Date: 2004/10/26 $$Author: ws150726 $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -17,7 +17,7 @@
 package Verilog::Netlist::Subclass;
 use Class::Struct;
 require Exporter;
-$VERSION = '2.300';
+$VERSION = '2.301';
 @ISA = qw(Exporter);
 @EXPORT = qw(structs);
 use strict;
@@ -190,12 +190,21 @@ Print a warning in a standard format.
 
 =back
 
-=head1 SEE ALSO
+=head1 DISTRIBUTION
 
-L<Verilog::Netlist>
+The latest version is available from CPAN and from
+L<http://www.veripool.com/verilog-perl.html>.
+
+Copyright 2000-2004 by Wilson Snyder.  This package is free software; you
+can redistribute it and/or modify it under the terms of either the GNU
+Lesser General Public License or the Perl Artistic License.
 
 =head1 AUTHORS
 
 Wilson Snyder <wsnyder@wsnyder.org>
 
+=head1 SEE ALSO
+
+L<Verilog::Netlist>
+
 =cut
